@@ -1,7 +1,7 @@
 package Shipwright::Logger;
 use strict;
 use warnings;
-use Carp;
+use Shipwright::Util;
 use Log::Log4perl;
 use Scalar::Util qw/blessed/;
 
@@ -55,7 +55,7 @@ sub _initialize_log4perl {
         $log_file  = $hash{log_file};
     }
 
-    $log_level = uc $log_level || 'FATAL';
+    $log_level = $log_level ? uc $log_level : 'FATAL';
     $log_file ||= '-';
     my %default = (
         'log4perl.rootLogger'             => "$log_level,File",
